@@ -7,7 +7,7 @@ class ChowkidarAuthMiddleware:
         context = info.context
         if not hasattr(info.context, 'ChowkidarIDResolved'):
             userID = resolve_user_from_request(context)
-            context.userID = userID
+            info.context.userID = userID
             info.context.ChowkidarIDResolved = True
         return next(root, info, **kwargs)
 
